xwem-patches
[Top] [All Lists]

Summary for xwem--main--2.2--patch-8

From: Zajcev Evgeny <lg@xxxxxxxx>
Subject: Summary for xwem--main--2.2--patch-8
Date: Sat, 23 Apr 2005 03:03:24 +0400 (MSD)
Location: lg@xxxxxxxxxxxxxx http://arch.xwem.org/2005/

Revision: xwem--main--2.2--patch-8
Archive: lg@xxxxxxxxxxxxxx
Creator: Zajcev Evgeny <lg@xxxxxxxx>
Date: Sat Apr 23 03:03:13 MSD 2005
Standard-date: 2005-04-22 23:03:13 GMT
Modified-files: extra/xwem-recover.el
New-patches: lg@xxxxxxxxxxxxxx/xwem--main--2.2--patch-8
Summary: typo fixes, thanks to Wassily Kondratiev
Keywords: typo

* extra/xwem-recover.el: desyncronisation -> desynchronisation


* added files

    {arch}/xwem/xwem--main/xwem--main--2.2/lg@xxxxxxxxxxxxxx/patch-log/patch-8

* modified files

--- orig/extra/xwem-recover.el
+++ mod/extra/xwem-recover.el
@@ -28,9 +28,9 @@
 
 ;;; Commentary:
 
-;; Sometimes xlib desyncronises with X server.  In such circumstatces
+;; Sometimes xlib desinchronises with X server.  In such circumstatces
 ;; only restarting helps.  This tool tries to recover xlib from
 ;; desyncronisation.  Desync may occur because XEmacs can block
 ;; whenever he want, and there no visible way to control it.
 
 ;; xwem-recover installs x error hooks and if many x errors occurs in
@@ -39,6 +39,9 @@
 ;; Any time you are feeling that something wrong, you can use
 ;; `xwem-recover-do-recover' command to force recovering.
 
+;; Use xwem-recover only if you are sure and you know what you are
+;; doing.
+
 ;;; Code:
 
 (require 'xwem-load)
@@ -74,7 +77,7 @@
 
 ;;;###autoload(autoload 'xwem-recover-do-recover "xwem-recover" "" t)
 (define-xwem-command xwem-recover-do-recover (xdpy)
-  "Recover XDPY from desyncronisation with X server."
+  "Recover XDPY from desinchronisation with X server."
   (xwem-interactive (list (xwem-dpy)))
 
   (flet ((old-x-dpy-filter (proc out)))
@@ -89,13 +92,12 @@
       ;; At this point all pending readed, so do cleanup things.  This
       ;; is not 100% will work.  In some circumstances this will only
       ;; add problems.
-      (xwem-recover-real-recover)
-      )))
+      (xwem-recover-real-recover))))
 
 (defun xwem-recover-xerr-hook (xdpy xerr)
   "Called when on display XDPY X error XERR occured.
 Check excedance of `xwem-recover-parameter' and if it seems like xlib
-got desyncronised with X server, start recovering routines."
+got desinchronised with X server, start recovering routines."
 
   (let ((ct (current-time)))
     (setq xwem-recover-errors (nreverse xwem-recover-errors))
@@ -111,10 +113,9 @@
               ;; Also recover when error code isn't recognized
               (not (memq (X-Event-xerror-code xerr)
                          '(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 128 
255))))
-      (xwem-message 'alarm "Recovering from desyncronisation .. (errors = 
%d)\n"
+      (xwem-message 'alarm "Recovering from desinchronisation .. (errors = 
%d)\n"
                    (length xwem-recover-errors))
-      (xwem-recover-do-recover xdpy))
-    ))
+      (xwem-recover-do-recover xdpy))))
 
 ;;;###autoload(autoload 'xwem-recover-turn-on "xwem-recover" "" t)
 (define-xwem-command xwem-recover-turn-on ()
@@ -28,9 +28,9 @@
 ;; only restarting helps.  This tool tries to recover xlib from
-;; desyncronisation.  Desync may occur because XEmacs can block
+;; desinchronisation.  Desync may occur because XEmacs can block
 ;; whenever he want, and there no visible way to control it.
 




<Prev in Thread] Current Thread [Next in Thread>
  • Summary for xwem--main--2.2--patch-8, Zajcev Evgeny <=